@@ -1,8 +1,9 @@
-import json
+import orjson
+from typing import Callable, List
 from functools import wraps
 
 
-def memlist(data):
+def memlist(data: List):
     """
     Remembers input/output of a function in python list.
 
@@ -49,7 +50,7 @@ def memlist(data):
     return decorator
 
 
-def memfile(filepath):
+def memfile(filepath: str):
     """
     Remembers input/output of a function in a jsonl file on disk.
 
@@ -74,7 +75,11 @@ def memfile(filepath):
         def wrapper(*args, **kwargs):
             result = func(*args, **kwargs)
             with open(filepath, "a") as f:
-                f.write(json.dumps({**kwargs, **result}) + "\n")
+                ser = orjson.dumps(
+                    {**kwargs, **result},
+                    option=orjson.OPT_NAIVE_UTC | orjson.OPT_SERIALIZE_NUMPY,
+                )
+                f.write(ser.decode("utf-8") + "\n")
             return result
 
         return wrapper
@@ -82,7 +87,7 @@ def memfile(filepath):
     return decorator
 
 
-def memfunc(callback):
+def memfunc(callback: Callable):
     """
     Remembers input/output of a function by printing.
 
